#
# spec file for package python-nibabel
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%define skip_python36 1
%define binaries nib-conform nib-convert nib-dicomfs nib-diff nib-ls nib-nifti-dx nib-roi nib-stats nib-tck2trk nib-trk2tck parrec2nii
Name:           python-nibabel
Version:        4.0.2
Release:        1.6
Summary:        Tool to access multiple neuroimaging data formats
License:        MIT
URL:            https://nipy.org/nibabel
Source:         https://files.pythonhosted.org/packages/source/n/nibabel/nibabel-%{version}.tar.gz
BuildRequires:  %{python_module setuptools >= 30.3.0}
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.17
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-Pillow
Recommends:     python-dicom >= 0.9.9
Recommends:     python-h5py
Recommends:     python-scipy
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module numpy >= 1.17}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
This package provides read +/- write access to some common medical and
neuroimaging file formats, including: ANALYZE (plain, SPM99, SPM2 and
later), GIFTI, NIfTI1, NIfTI2, CIFTI-2, MINC1, MINC2, AFNI BRIK/HEAD,
MGH and ECAT as well as Philips PAR/REC. We can read and write
FreeSurfer geometry, annotation and morphometry files. There is some
very limited support for DICOM.

%prep
%setup -q -n nibabel-%{version}

%build
%python_build

%install
%python_install
for b in %{binaries}; do
  %python_clone -a %{buildroot}%{_bindir}/$b
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
for b in %{binaries}; do
  %python_install_alternative $b
done

%postun
for b in %{binaries}; do
  %python_uninstall_alternative $b
done

%files %{python_files}
%doc AUTHOR Changelog README.rst
%license COPYING
%python_alternative %{_bindir}/nib-conform
%python_alternative %{_bindir}/nib-convert
%python_alternative %{_bindir}/nib-dicomfs
%python_alternative %{_bindir}/nib-diff
%python_alternative %{_bindir}/nib-ls
%python_alternative %{_bindir}/nib-nifti-dx
%python_alternative %{_bindir}/nib-roi
%python_alternative %{_bindir}/nib-stats
%python_alternative %{_bindir}/nib-tck2trk
%python_alternative %{_bindir}/nib-trk2tck
%python_alternative %{_bindir}/parrec2nii
%{python_sitelib}/*

%changelog
* Thu Oct  6 2022 Markéta Machová <mmachova@suse.com>
- Update to 4.0.2
  * many changes, see Changelog
  * nib-convert CLI tool to make image type and data dtype conversion
    accessible via the command line.
  * Allow dtypes to be passed to Analyze-like images at __init__()
    and to_filename()
  * Allow compressed GIFTI images
  * Add zstd compression support
  * Test on Python 3.10
  * Passing (u)int64 arrays to Nifti1Image and subclasses will warn
    unless a header or dtype option is passed; in the future this will
    become an error. Additionally, passing int or 'int' to set_data_dtype()
    now raises an error, requiring an explicit numpy dtype to make 64-bit
    integer images.
  * Drop support for Python 3.6, Numpy < 1.17
  * Fully removed the APIs, which have raised errors on use since 3.0
- Drop upstreamed 983.patch and purge-nose.patch
* Wed Mar 31 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add upstream patch to fix test on Backports:SLE-15-SP3:
  * 983.patch
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- skip python 36
* Fri Jul 10 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.1.1
  * Conformation function (``processing.conform``) and CLI tool
    (``nib-conform``) to apply shape, orientation and zooms (pr/853) (Jakub
    Kaczmarzyk, reviewed by CM, YOH)
  * Affine rescaling function (``affines.rescale_affine``) to update
    dimensions and voxel sizes (pr/853) (CM, reviewed by Jakub Kaczmarzyk)
  * ``kw_only_meth``/``kw_only_func`` decorators are deprecated (pr/848)
    (RM, reviewed by CM)
- Add patch purge-nose.patch
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.1:
  * Test failed by using array method on tuple. (pr/860) (Ben Darwin, reviewed by CM)
  * Validate ExpiredDeprecationErrors, promoted by 3.0 release from DeprecationWarnings. (pr/857) (CM)
  * Improve testing of data scaling in ArrayProxy API (pr/847) (CM, reviewed by Alejandro de la Vega)
  * Document SpatialImage.slicer interface (pr/846) (CM)
  * get_fdata(dtype=np.float32) will attempt to avoid casting data to np.float64 when scaling parameters would otherwise promote the data type unnecessarily. (pr/833) (CM, reviewed by Ross Markello)
  * ArraySequence now supports a large set of Python operators to combine or update in-place. (pr/811) (MC, reviewed by Serge Koudoro, Philippe Poulin, CM, MB)
  * Warn, rather than fail, on DICOMs with unreadable Siemens CSA tags (pr/818) (Henry Braun, reviewed by CM)
  * Improve clarity of coordinate system tutorial (pr/823) (Egor Panfilov, reviewed by MB)
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to version 2.5.1
  + Enhancements
  * Ignore endianness in ``nib-diff`` if values match
  + Bug fixes
  * Correctly handle Philips DICOMs w/ derived volume
  * Raise CSA tag limit to 1000, parametrize for future relaxing
  * Coerce data types to match NIfTI intent codes when writing GIFTI data
    arrays
  + Maintenance
  * Require h5py 2.10 for Windows + Python < 3.6 to resolve unexpected dtypes
    in Minc2 data
  + API changes and deprecations
  * Deprecate ``nicom.dicomwrappers.Wrapper.get_affine()`` in favor of ``affine``
    property; final removal in nibabel 4.0
- Update to version 2.5.0
  + Enhancements
  * Add SerializableImage class with to/from_bytes methods
  * Check CIFTI-2 data shape matches shape described by header
  + Bug fixes
  * Handle stricter numpy casting rules in tests
  * TRK header fields flipped in files written on big-endian systems
  * Load multiframe ECAT images with Python 3
  + Maintenance
  * Fix CodeCov paths on Appveyor for more accurate coverage
  * Move to setuptools and reduce use ``nisext`` functions
  * Better handle test setup/teardown
  + API changes and deprecations
  * Effect threatened warnings and set some deprecation timelines
  * Trackvis methods now default to v2 formats
  * ``nibabel.trackvis`` scheduled for removal in nibabel 4.0
  * ``nibabel.minc`` and ``nibabel.MincImage`` will be removed in nibabel 3.0
- Drop upstream-included fix_numpy_1_17.patch
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Add fix_numpy_1_17.patch to fix building with numpy 1.17.0
  From: gh#/nipy/nibabel#768
* Fri Jul 26 2019 Todd R <toddrme2178@gmail.com>
- Initial version
